# Product


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**djstripe_product** | [**DjStripeProduct**](DjStripeProduct.md) |  | 
**prices** | [**list[DjStripePrice]**](DjStripePrice.md) |  | 
**deleted** | **datetime** |  | [readonly] 
**created_dt** | **datetime** |  | [readonly] 
**updated_dt** | **datetime** |  | [readonly] 
**sku** | **str** |  | 
**slug** | **str** |  | 
**unit_label** | **str** |  | 
**name** | **str** |  | 
**description** | **str** |  | 
**statement_descriptor** | **str** |  | 
**images** | **list[str]** |  | [optional] 
**is_active** | **bool** |  | [optional] 
**is_shippable** | **bool** |  | 
**is_preorder** | **bool** |  | 
**is_subscription** | **bool** |  | 
**stripe_price_lookup_key** | **str** |  | [optional] 
**stripe_product_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


